@@ -181,7 +181,8 @@ pub struct RecordUpdate {
 
 /// A `Record` represents a single accountable unit.
 ///
-/// Records can be sent to and received from Auditor with the [`AuditorClient`](`crate::client::AuditorClient`).
+/// Records can be sent to and received from Auditor with the
+/// [`AuditorClient`](../../auditor_client/index.html) crate.
 /// When initially inserting a record in Auditor, the record is represented as [`RecordAdd`].
 /// The `stop_time` can be updated at a later time by pushing a [`RecordUpdate`] to Auditor.
 ///
@@ -191,8 +192,8 @@ pub struct RecordUpdate {
 ///
 /// Retrieve all records from Auditor:
 ///
-/// ```no_run
-/// # use auditor::client::{AuditorClientBuilder, ClientError};
+/// ```ignore
+/// # use auditor_client::{AuditorClientBuilder, ClientError};
 /// #
 /// # fn main() -> Result<(), ClientError> {
 /// // Create client by using the builder
@@ -223,11 +224,11 @@ pub struct Record {
 }
 
 #[doc(hidden)]
-#[derive(Serialize, Deserialize, Clone, Debug, PartialEq, Eq, PartialOrd, Ord, sqlx::FromRow)]
+#[derive(Serialize, Deserialize, Clone, Debug, PartialEq, Eq, sqlx::FromRow)]
 pub struct RecordDatabase {
     pub record_id: String,
-    pub meta: Option<Vec<(String, Vec<String>)>>,
-    pub components: Option<Vec<Component>>,
+    pub meta: Option<serde_json::Value>,
+    pub components: Option<serde_json::Value>,
     pub start_time: Option<DateTime<Utc>>,
     pub stop_time: Option<DateTime<Utc>>,
     pub runtime: Option<i64>,
@@ -559,6 +560,42 @@ impl TryFrom<RecordTest> for RecordUpdate {
     }
 }
 
+impl From<RecordAdd> for Record {
+    fn from(r: RecordAdd) -> Self {
+        let runtime = r.stop_time.map(|t| (t - r.start_time).num_seconds());
+        Self {
+            record_id: r.record_id.to_string(),
+            meta: r.meta.map(Into::<Meta>::into),
+            components: if r.components.is_empty() {
+                None
+            } else {
+                Some(r.components)
+            },
+            start_time: Some(r.start_time),
+            stop_time: r.stop_time,
+            runtime,
+        }
+    }
+}
+
+impl From<RecordUpdate> for Record {
+    fn from(r: RecordUpdate) -> Self {
+        let runtime = r.start_time.map(|t| (r.stop_time - t).num_seconds());
+        Self {
+            record_id: r.record_id.to_string(),
+            meta: r.meta.map(Into::<Meta>::into),
+            components: if r.components.is_empty() {
+                None
+            } else {
+                Some(r.components)
+            },
+            start_time: r.start_time,
+            stop_time: Some(r.stop_time),
+            runtime,
+        }
+    }
+}
+
 impl TryFrom<Record> for RecordUpdate {
     type Error = Error;
 
@@ -626,7 +663,13 @@ impl TryFrom<RecordDatabase> for Record {
             runtime,
         } = other;
         let meta = if let Some(meta) = meta {
-            Some(meta.try_into()?)
+            serde_json::from_value(meta).ok()
+        } else {
+            None
+        };
+
+        let components = if let Some(components) = components {
+            serde_json::from_value(components).ok()
         } else {
             None
         };
