@@ -5,6 +5,7 @@ use once_cell::sync::Lazy;
 use sqlx::{Connection, Executor, PgConnection, PgPool};
 use std::net::TcpListener;
 use tracing_subscriber::filter::LevelFilter;
+use urlencoding::encode;
 use uuid::Uuid;
 
 static TRACING: Lazy<()> = Lazy::new(|| {
@@ -35,7 +36,17 @@ impl TestApp {
 
     pub async fn add_record<T: serde::Serialize>(&self, record: &T) -> reqwest::Response {
         reqwest::Client::new()
-            .post(&format!("{}/add", &self.address))
+            .post(&format!("{}/record", &self.address))
+            .header("Content-Type", "application/json")
+            .json(record)
+            .send()
+            .await
+            .expect("Failed to execute request.")
+    }
+
+    pub async fn bulk_insert<T: serde::Serialize>(&self, record: &T) -> reqwest::Response {
+        reqwest::Client::new()
+            .post(&format!("{}/records", &self.address))
             .header("Content-Type", "application/json")
             .json(record)
             .send()
@@ -45,7 +56,7 @@ impl TestApp {
 
     pub async fn get_records(&self) -> reqwest::Response {
         reqwest::Client::new()
-            .get(&format!("{}/get", &self.address))
+            .get(&format!("{}/records", &self.address))
             .send()
             .await
             .expect("Failed to execute request.")
@@ -55,11 +66,12 @@ impl TestApp {
         &self,
         timestamp: T,
     ) -> reqwest::Response {
+        let timestamp_str = timestamp.as_ref();
+        let encoded_since = encode(timestamp_str);
         reqwest::Client::new()
             .get(&format!(
-                "{}/get/started/since/{}",
-                &self.address,
-                timestamp.as_ref()
+                "{}/records?start_time[gte]={}",
+                &self.address, encoded_since
             ))
             .send()
             .await
@@ -70,16 +82,39 @@ impl TestApp {
         &self,
         timestamp: T,
     ) -> reqwest::Response {
+        let timestamp_str = timestamp.as_ref();
+        let encoded_since = encode(timestamp_str);
         reqwest::Client::new()
             .get(&format!(
-                "{}/get/stopped/since/{}",
-                &self.address,
-                timestamp.as_ref()
+                "{}/records?stop_time[gte]={}",
+                &self.address, encoded_since
             ))
             .send()
             .await
             .expect("Failed to execute request.")
     }
+
+    pub async fn advanced_queries<T: AsRef<str> + std::fmt::Display>(
+        &self,
+        query_string: T,
+    ) -> reqwest::Response {
+        reqwest::Client::new()
+            .get(&format!("{}/records?{}", &self.address, query_string))
+            .send()
+            .await
+            .expect("Failed to execute queries.")
+    }
+
+    pub async fn get_single_record<T: AsRef<str> + std::fmt::Display>(
+        &self,
+        record_id: T,
+    ) -> reqwest::Response {
+        reqwest::Client::new()
+            .get(&format!("{}/record/{}", &self.address, record_id))
+            .send()
+            .await
+            .expect("Failed to execute queries.")
+    }
 }
 
 pub async fn spawn_app() -> TestApp {
