@@ -3,7 +3,6 @@
 import asyncio
 from pyauditor import AuditorClientBuilder, Record
 import datetime
-import pytz
 from tzlocal import get_localzone
 
 
@@ -27,7 +26,7 @@ async def main():
     # datetimes sent to auditor MUST BE in UTC.
     start = datetime.datetime(
         2021, 12, 6, 16, 29, 43, 79043, tzinfo=local_tz
-    ).astimezone(pytz.utc)
+    ).astimezone(datetime.timezone.utc)
     record = Record(record_id, start)
 
     await client.add(record)
@@ -37,10 +36,10 @@ async def main():
     assert len(records) == 1
     record = records[0]
     assert record.record_id == record_id
-    assert record.start_time.replace(tzinfo=pytz.utc) == start
+    assert record.start_time.replace(tzinfo=datetime.timezone.utc) == start
 
     print("Updating record: Adding stop time")
-    stop = datetime.datetime.now(tz=local_tz).astimezone(pytz.utc)
+    stop = datetime.datetime.now(tz=local_tz).astimezone(datetime.timezone.utc)
 
     record = record.with_stop_time(stop)
     await client.update(record)
@@ -50,8 +49,8 @@ async def main():
     assert len(records) == 1
     record = records[0]
     assert record.record_id == record_id
-    assert record.start_time.replace(tzinfo=pytz.utc) == start
-    assert record.stop_time.replace(tzinfo=pytz.utc) == stop
+    assert record.start_time.replace(tzinfo=datetime.timezone.utc) == start
+    assert record.stop_time.replace(tzinfo=datetime.timezone.utc) == stop
 
     print("Script test_add_update.py finished.")
 
